# v1.2.1 (2018-02-19)

- Convert docs to md for PyPI compatibility.

# v1.2.0 (2018-02-18)

-   Remove asserts.
-   Account for dictionary values in decoded metar.

# v1.1.0 (2017-12-01)

-   Update readme.
-   Cleanup exception handling.
-   Add unit and integration tests with vcrpy.
-   Cleanup flake8 warnings.
-   Add config for travis integration testing.

# v1.0.6 (2017-09-24)

-   Remove docs directory.
-   Fix manifest.

# v1.0.5 (2017-09-24)

# v1.0.4 (2017-09-24)

-   Fix license trove classifier.

# v1.0.3 (2017-09-24)

-   Remove universal flag from setup config.

# v1.0.2 (2017-09-24)

-   Fix doc extensions in setup.

# v1.0.1 (2017-09-24)

-   Fix manifest.

# v1.0.0 (2017-09-24)

-   Cleanup flake8 warnings.
-   Remove config in favor of geopy to get location for seven day
    forecast.
-   Migrate to f'{strings}'
-   Migrate to adoc from rst.
-   Cleanup code.
-   Update readme and docs.

# v0.3.0 (2017-08-09)

-   Remove cert and use certifi for NWS API.
-   Convert elevation to feet.

# v0.2.1 (2017-08-09)

-   Attempt to fix cert.

# v0.2.0 (2017-08-08)

-   Attempt to fix cert.

# v0.1.0 (2017-01-14)

-   First release on PyPI.

